0.3.1 (2021-11-11)
==================

Bugfixes
--------

- Fix core Odoo addons path discovery for Odoo < 13.0. (`#18 <https://github.com/sbidoul/manifestoo/issues/18>`_)

Features
--------

- Update base addons list


0.3 (2021-10-06)
================

Features
--------

- Add support for Odoo 15, and update Odoo base addons lists. (`#15 <https://github.com/sbidoul/manifestoo/issues/15>`_)


Improved Documentation
----------------------

- Document addons selection and search path options. (`#3 <https://github.com/sbidoul/manifestoo/issues/3>`_)


0.2 (2021-05-25)
================

Deprecations and Removals
-------------------------

- Deprecate ``--separator`` as a global option. It belongs to commands that print
  lists. (`#1 <https://github.com/sbidoul/manifestoo/issues/1>`_)


0.1 (2021-05-23)
================

First release.
